@@ -21,9 +21,9 @@
 #ifndef __TOMOE_GTK_H_INCLUDED__
 #define __TOMOE_GTK_H_INCLUDED__
 
-#include <tomoe_canvas.h>
-#include <tomoe_char_table.h>
-#include <tomoe_window.h>
-#include <tomoe_stroke_search.h>
+#include <tomoe-canvas.h>
+#include <tomoe-char-table.h>
+#include <tomoe-window.h>
+#include <tomoe-stroke-search.h>
 
 #endif /* __TOMOE_GTK_H_INCLUDED__ */
