@@ -6,7 +6,7 @@ main (int argc, char *argv[])
 {
 	GtkWidget *win;
 
-	g_setenv ("TOMOE_CONFIG_FILE", "./test-config.xml", FALSE);
+	/*g_setenv ("TOMOE_CONFIG_FILE", "./test-config.xml", FALSE);*/
 	gtk_init (&argc, &argv);
 	win = tomoe_window_new ();
 	g_signal_connect (G_OBJECT (win), "response",
